==> haskell-cookie-0.4.5-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cookie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cookie
version:              0.4.5
visibility:           public
id:                   cookie-0.4.5-9B2dS5wCPmq3hZq3aUzZ9g
key:                  cookie-0.4.5-9B2dS5wCPmq3hZq3aUzZ9g
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://github.com/snoyberg/cookie
synopsis:             HTTP cookie parsing and rendering
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/cookie>.

category:             Web, Yesod
abi:                  8e857c8df4197cb29778eee7c259aced
exposed:              True
exposed-modules:      Web.Cookie
import-dirs:          /usr/lib/ghc-8.10.2/site-local/cookie-0.4.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/cookie-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/cookie-0.4.5
hs-libraries:         HScookie-0.4.5-9B2dS5wCPmq3hZq3aUzZ9g
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8 deepseq-1.4.4.0
    text-1.2.3.2 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-cookie/html/cookie.haddock
haddock-html:         /usr/share/doc/haskell-cookie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cookie-0.4.5-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cookie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cookie
version:              0.4.5
visibility:           public
id:                   cookie-0.4.5-Cr058gEywdbK8YE1EhasZd
key:                  cookie-0.4.5-Cr058gEywdbK8YE1EhasZd
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://github.com/snoyberg/cookie
synopsis:             HTTP cookie parsing and rendering
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/cookie>.

category:             Web, Yesod
abi:                  17ae21e546b8eb471de51cf6dd812843
exposed:              True
exposed-modules:      Web.Cookie
import-dirs:          /usr/lib/ghc-8.10.3/site-local/cookie-0.4.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/cookie-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/cookie-0.4.5
hs-libraries:         HScookie-0.4.5-Cr058gEywdbK8YE1EhasZd
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8 deepseq-1.4.4.0
    text-1.2.4.1 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-cookie/html/cookie.haddock
haddock-html:         /usr/share/doc/haskell-cookie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
